@@ -2,7 +2,7 @@
 
 baddeps=""
 # check deps
-python3 -m pep517.__init__ || baddeps="python3-pep517"
+python3 -m build.__init__ || baddeps="python3-build"
 if [ -n "${baddeps}" ]; then
     echo "${baddeps} must be installed!"
     exit 1
@@ -22,5 +22,5 @@ git commit -s -m "Release ${version}" || exit 1
 git push || exit 1
 git tag -a -m "Release ${version}" ${version} || exit 1
 git push origin ${version} || exit 1
-python3 -m pep517.build . || exit 1
+python3 -m build . || exit 1
 twine upload -r pypi dist/${name}-${version}* || exit 1
