@@ -23,6 +23,7 @@ any particular class or even in another file but outside of a class."""
 import re
 from decimal import Decimal
 
+import fedfind.const
 import fedfind.helpers
 import fedfind.release
 
@@ -71,7 +72,7 @@ def fedora_release_sort(string):
     function, '22 Alpha TC1' > '22 Alpha'.
     """
     # Some MILESTONES are substrings of COMPOSES so we do Cs first
-    for (orig, repl) in COMPOSE_PAIRS + MILESTONE_PAIRS:
+    for orig, repl in COMPOSE_PAIRS + MILESTONE_PAIRS:
         string = string.replace(orig, repl)
     return string
 
@@ -88,12 +89,12 @@ def triplet_sort(release, milestone, compose):
     meant to *do* anything with the tuple but compare it to another
     similar tuple.
     """
-    for (orig, repl) in MILESTONE_PAIRS:
+    for orig, repl in MILESTONE_PAIRS:
         milestone = milestone.replace(orig, repl)
         if not milestone:
             # ('23', 'Final', '') == ('23', '', '')
             milestone = "800"
-    for (orig, repl) in COMPOSE_PAIRS:
+    for orig, repl in COMPOSE_PAIRS:
         compose = compose.replace(orig, repl)
         if not compose:
             compose = "999"
@@ -121,7 +122,7 @@ def triplet_sort(release, milestone, compose):
 def triplet_unsort(release, milestone, compose):
     """Reverse of triplet_sort."""
     (release, milestone, compose) = (str(release), str(milestone), str(compose))
-    for (repl, orig) in MILESTONE_PAIRS:
+    for repl, orig in MILESTONE_PAIRS:
         milestone = milestone.replace(orig, repl)
         if milestone == "800":
             milestone = "Final"
@@ -135,7 +136,7 @@ def triplet_unsort(release, milestone, compose):
         (comp, respin) = compose.split(".")
         compose = f"{comp}.n.{respin}"
     else:
-        for (repl, orig) in COMPOSE_PAIRS:
+        for repl, orig in COMPOSE_PAIRS:
             compose = compose.replace(orig, repl)
             if compose == "999":
                 compose = ""
@@ -192,6 +193,10 @@ def cid_to_event(cid):
     date = parsed["date"]
     typ = parsed["compose_type"]
     respin = parsed["respin"]
+    if not release.isdigit() and release != "rawhide":
+        # we don't have validation events for whatever this is
+        # (probably ELN)
+        raise ValueError(f"No validation events for non-integer release {release} from {cid}!")
     if dist not in ("Fedora", "Fedora-Modular", "Fedora-IoT"):
         # we only have validation events for these composes ATM -
         # not e.g. FedoraRespin or Fedora-Atomic ones
@@ -203,6 +208,8 @@ def cid_to_event(cid):
         # we need to get the label and parse that
         ffrel = fedfind.release.get_release(cid=cid)
         if not ffrel.label:
+            if ffrel.status not in fedfind.const.PUNGI_SUCCESS:
+                raise ValueError(f"Compose {cid} failed, cannot determine event.")
             raise ValueError(
                 f"{cid} looks like a production compose, but found "
                 "no label! Cannot determine event."
