@@ -265,6 +265,8 @@ class TcmsGeneratorList(mwclient.listing.GeneratorList):
         if name.startswith("Test Day:") and not name.endswith("/ru"):
             if not "metadata" in name.lower() and not "rendercheck" in name.lower():
                 return self._get_tcms_testday(name, info)
+        if name.startswith("Template:") and name.endswith("matrix"):
+            return wikitcms.page.ResultPage(self.site, name, info)
 
         # otherwise, we'll just bail out here
         raise NoPageWarning(name)
