@@ -33,7 +33,6 @@ import fedfind.helpers
 import fedfind.release
 from mwclient import errors as mwe
 from mwclient import page as mwp
-import pytz
 
 from wikitcms.exceptions import NoPageError, NotFoundError, TooManyError
 import wikitcms.helpers
@@ -100,7 +99,11 @@ class Page(mwp.Page):
         """Date the page was created. Used for sorting and seeing how
         long it's been since the last event, when creating new events.
         """
-        revs = self.revisions(limit=1, dir="newer", prop="timestamp")
+        try:
+            revs = self.revisions(max_items=1, dir="newer", prop="timestamp")
+        except TypeError:
+            # mwclient < 0.11.0
+            revs = self.revisions(limit=1, dir="newer", prop="timestamp")
         try:
             origrev = next(revs)
         except StopIteration:
@@ -148,7 +151,144 @@ class Page(mwp.Page):
         return ret
 
 
-class ValidationPage(Page):
+class ResultPage(Page):
+    """A page containing result sections. This will usually be a
+    ValidationPage (see below), but can also be a matrix template
+    page, and it's occasionally useful to be able to inspect the
+    result sections of those.
+    """
+
+    @property
+    def results_sections(self):
+        """A list of the sections in the page which (most likely)
+        contain test results. Takes all the sections in the page,
+        finds the one one which looks like the first "test results"
+        section and returns that section and those that follow it - or
+        returns all sections after the Key section, if it can't find
+        one which looks like the first results section.
+        """
+        secs = self.sections
+        if not secs:
+            # empty page or some other malarkey
+            return secs
+        first = None
+        for i, sec in enumerate(secs):
+            if "Test Matri" in sec["line"] or "Test Areas" in sec["line"]:
+                first = i
+                break
+            if "Key" in sec["line"]:
+                first = i + 1
+        return secs[first:]
+
+    def get_resultrows(self, statuses=None, transferred=True):
+        """Returns the result.ResultRow objects representing all the
+        page's table rows containing test results.
+        """
+        sections = self.results_sections
+        if not sections:
+            return list()
+        rows = list()
+        pagetext = self.text()
+        comment = re.compile("<!--.*?-->", re.S)
+        for i, sec in enumerate(sections):
+            # since sections nest, we don't actually want *all* the
+            # text in any given section as then we'd multiple-count
+            # results.
+            # what we actually want is the text from the start of each
+            # section to the start of the *next* section, even if the
+            # next section is a child of the current section. so we
+            # count each result once, in the lowest-level section it's
+            # a part of
+            nextstart = None
+            try:
+                # sections from templates have byteoffset None. since
+                # we happen to know there will never be results in such
+                # a section, just keep going till we find one with a
+                # byteoffset. this is all a horrible hack anyway
+                inc = 0
+                while not nextstart:
+                    inc += 1
+                    nextstart = sections[i + inc]["byteoffset"]
+            except IndexError:
+                pass
+            section = sec["line"]
+            secid = sec["index"]
+            sectext = pagetext[sec["byteoffset"] : nextstart]
+            # strip comments
+            sectext = comment.sub("", sectext)
+            newrows = wikitcms.result.find_resultrows(
+                sectext, section, secid, statuses, transferred
+            )
+            rows.extend(newrows)
+        return rows
+
+    def find_resultrow(self, testcase="", section="", testname="", env=""):
+        """Return exactly one result row with the desired attributes,
+        or raise an exception (if more or less than one row is found).
+        The Installation page contains some rows in the same section
+        with the same testcase and testname, but each row provides
+        a different set of envs, so these can be uniquely identified
+        by specifying the desired env.
+        """
+        rows = self.get_resultrows()
+        if not rows:
+            raise NoPageError("Page does not exist or has no result rows.")
+
+        # Find the right row
+        nrml = wikitcms.helpers.normalize
+        gotrows = [
+            r for r in rows if nrml(testcase) == nrml(r.testcase) or nrml(testcase) == nrml(r.name)
+        ]
+        if gotrows:
+            rows = gotrows
+        else:
+            # fuzzier match
+            rows = [
+                r
+                for r in rows
+                if nrml(testcase) in nrml(r.testcase) or nrml(testcase) in nrml(r.name)
+            ]
+        if len(rows) > 1 and section:
+            rows = [r for r in rows if nrml(section) in nrml(r.section)]
+        if len(rows) > 1 and testname:
+            rows = [r for r in rows if nrml(testname) in nrml(r.name)]
+        if len(rows) > 1 and env:
+            # the way this match is done must be kept in line with the
+            # corresponding match in add_results, below
+            rows = [r for r in rows if nrml(env) in [nrml(renv) for renv in r.results.keys()]]
+        # try a more precise name match - e.g. "upgrade_dnf" vs.
+        # "upgrade_dnf_encrypted"
+        if len(rows) > 1:
+            newrows = [
+                r
+                for r in rows
+                if nrml(testcase) == nrml(r.testcase)
+                or nrml(testcase) == nrml(r.name)
+                or nrml(testname) == nrml(r.name)
+            ]
+            if len(newrows) == 1:
+                rows = newrows
+        # also try a more precise section name match - e.g.
+        # "Release-blocking desktops" vs.
+        # "Non release-blocking desktops":
+        # https://pagure.io/fedora-qa/python-wikitcms/issue/4
+        if len(rows) > 1:
+            newrows = [r for r in rows if nrml(section) == nrml(r.section)]
+            if len(newrows) == 1:
+                rows = newrows
+        # let's also see if non-normalized section matching helps
+        if len(rows) > 1:
+            newrows = [r for r in rows if section in r.section]
+            if len(newrows) == 1:
+                rows = newrows
+        if not rows:
+            raise NotFoundError("Specified row cannot be found.")
+        if len(rows) > 1:
+            raise TooManyError("More than one matching row found.")
+        return rows[0]
+
+
+class ValidationPage(ResultPage):
     """A parent class for different types of release validation event
     pages, containing common properties and methods. Required
     attributes: version, shortver, seedtext. "dist" lets us create
@@ -198,113 +338,6 @@ class ValidationPage(Page):
             self.release, self.milestone, self.compose
         ) + (self.testtype,)
 
-    @property
-    def results_sections(self):
-        """A list of the sections in the page which (most likely)
-        contain test results. Takes all the sections in the page,
-        finds the one one which looks like the first "test results"
-        section and returns that section and those that follow it - or
-        returns all sections after the Key section, if it can't find
-        one which looks like the first results section.
-        """
-        secs = self.sections
-        if not secs:
-            # empty page or some other malarkey
-            return secs
-        first = None
-        for i, sec in enumerate(secs):
-            if "Test Matri" in sec["line"] or "Test Areas" in sec["line"]:
-                first = i
-                break
-            if "Key" in sec["line"]:
-                first = i + 1
-        return secs[first:]
-
-    def get_resultrows(self, statuses=None, transferred=True):
-        """Returns the result.ResultRow objects representing all the
-        page's table rows containing test results.
-        """
-        sections = self.results_sections
-        if not sections:
-            return list()
-        rows = list()
-        pagetext = self.text()
-        comment = re.compile("<!--.*?-->", re.S)
-        for i, sec in enumerate(sections):
-            try:
-                nextsec = sections[i + 1]
-            except IndexError:
-                nextsec = None
-            section = sec["line"]
-            secid = sec["index"]
-            if nextsec:
-                sectext = pagetext[sec["byteoffset"] : nextsec["byteoffset"]]
-            else:
-                sectext = pagetext[sec["byteoffset"] :]
-            # strip comments
-            sectext = comment.sub("", sectext)
-            newrows = wikitcms.result.find_resultrows(
-                sectext, section, secid, statuses, transferred
-            )
-            rows.extend(newrows)
-        return rows
-
-    def find_resultrow(self, testcase="", section="", testname="", env=""):
-        """Return exactly one result row with the desired attributes,
-        or raise an exception (if more or less than one row is found).
-        The Installation page contains some rows in the same section
-        with the same testcase and testname, but each row provides
-        a different set of envs, so these can be uniquely identified
-        by specifying the desired env.
-        """
-        rows = self.get_resultrows()
-        if not rows:
-            raise NoPageError("Page does not exist or has no result rows.")
-
-        # Find the right row
-        nrml = wikitcms.helpers.normalize
-        rows = [
-            r for r in rows if nrml(testcase) in nrml(r.testcase) or nrml(testcase) in nrml(r.name)
-        ]
-        if len(rows) > 1 and section:
-            rows = [r for r in rows if nrml(section) in nrml(r.section)]
-        if len(rows) > 1 and testname:
-            rows = [r for r in rows if nrml(testname) in nrml(r.name)]
-        if len(rows) > 1 and env:
-            # the way this match is done must be kept in line with the
-            # corresponding match in add_results, below
-            rows = [r for r in rows if nrml(env) in [nrml(renv) for renv in r.results.keys()]]
-        # try a more precise name match - e.g. "upgrade_dnf" vs.
-        # "upgrade_dnf_encrypted"
-        if len(rows) > 1:
-            newrows = [
-                r
-                for r in rows
-                if nrml(testcase) == nrml(r.testcase)
-                or nrml(testcase) == nrml(r.name)
-                or nrml(testname) == nrml(r.name)
-            ]
-            if len(newrows) == 1:
-                rows = newrows
-        # also try a more precise section name match - e.g.
-        # "Release-blocking desktops" vs.
-        # "Non release-blocking desktops":
-        # https://pagure.io/fedora-qa/python-wikitcms/issue/4
-        if len(rows) > 1:
-            newrows = [r for r in rows if nrml(section) == nrml(r.section)]
-            if len(newrows) == 1:
-                rows = newrows
-        # let's also see if non-normalized section matching helps
-        if len(rows) > 1:
-            newrows = [r for r in rows if section in r.section]
-            if len(newrows) == 1:
-                rows = newrows
-        if not rows:
-            raise NotFoundError("Specified row cannot be found.")
-        if len(rows) > 1:
-            raise TooManyError("More than one matching row found.")
-        return rows[0]
-
     def update_current(self):
         """Make the Current convenience redirect page on the wiki for
         the given test type point to this page.
@@ -343,7 +376,7 @@ class ValidationPage(Page):
         # can be left out of the summary text
         notrows = list()
         newtext = oldtext = self.text()
-        for (row, results) in resultsdict.items():
+        for row, results in resultsdict.items():
             # It's possible that we have rows with identical text in
             # different page sections; this is why 'secid' is an attr
             # of ResultRows. To make sure we edit the correct row,
@@ -360,7 +393,7 @@ class ValidationPage(Page):
             oldrow = row.origtext
             cells = oldrow.split("\n|")
 
-            for (env, result) in results:
+            for env, result in results:
                 if not env in row.results:
                     # the env passed wasn't precisely one of the row's
                     # envs. let's see if we can make a safe guess. If
@@ -573,6 +606,7 @@ class DownloadPage(Page):
             (("lxde",), 70),
             (("source",), -10),
         )
+        typescores = ((("live-osbuild",), -300),)
         # Start by iterating over all images and grouping them by load
         # (that's imagedict) and keeping a record of each arch we
         # encounter (that's arches).
@@ -589,12 +623,15 @@ class DownloadPage(Page):
             # assign a 'score' to the image; this will be used for
             # ordering the download table's rows.
             img["score"] = 0
-            for (values, score) in archscores:
+            for values, score in archscores:
                 if img["arch"] in values:
                     img["score"] = score
-            for (values, score) in loadscores:
+            for values, score in loadscores:
                 if img["subvariant"].lower() in values:
                     img["score"] += score
+            for values, score in typescores:
+                if img["type"].lower() in values:
+                    img["score"] += score
             # The dict values are lists of images. We could use a
             # DefaultDict here, but faking it is easy too.
             if desc in imagedict:
@@ -619,7 +656,7 @@ class DownloadPage(Page):
             # Add a column for each arch
             table += f" !! {arch}"
         table += "\n"
-        for (subvariant, imgs) in imagedict.items():
+        for subvariant, imgs in imagedict.items():
             # Add a row for each subvariant
             table += "|-\n"
             table += f"| {subvariant}\n"
@@ -660,15 +697,22 @@ class AMIPage(Page):
         have to query this information out of datagrepper, that's the
         only place where it's available.
         """
+        arches = ("x86_64", "aarch64")
         # pylint: disable=too-many-locals
         text = ""
         # first, let's get the information out of datagrepper. We'll
         # ask for messages up to 2 days after the event date.
-        date = fedfind.helpers.parse_cid(self.event.ff_release.cid, dic=True)["date"]
-        start = datetime.datetime.strptime(date, "%Y%m%d").replace(tzinfo=pytz.utc)
+        ciddic = fedfind.helpers.parse_cid(self.event.ff_release.cid, dic=True)
+        start = datetime.datetime.strptime(ciddic["date"], "%Y%m%d").replace(
+            tzinfo=datetime.timezone.utc
+        )
         end = start + datetime.timedelta(days=2)
-        url = "https://apps.fedoraproject.org/datagrepper/raw"
-        url += "?topic=org.fedoraproject.prod.fedimg.image.publish"
+        topics = [f"aws.{self.event.milestone.lower()}.Cloud_Base.{arch}" for arch in arches]
+        url = "https://apps.fedoraproject.org/datagrepper/raw?"
+        for i, topic in enumerate(topics):
+            if i > 0:
+                url += "&"
+            url += f"topic=org.fedoraproject.prod.fedora_image_uploader.published.v1.{topic}"
         # convert to epoch (this is what datagrepper wants)
         url += f"&start={start.timestamp()}&end={end.timestamp()}"
         json = fedfind.helpers.download_json(url)
@@ -680,45 +724,35 @@ class AMIPage(Page):
             msgs.extend(newjson["raw_messages"])
 
         # now let's find the messages for our event compose
-        ours = [msg["msg"] for msg in msgs if msg["msg"]["compose"] == self.event.ff_release.cid]
+        ours = [msg["msg"] for msg in msgs if msg["msg"]["compose_id"] == self.event.ff_release.cid]
 
-        def _table_line(msg):
+        def _table_line(region, ami):
             """Convenience function for generating a table line."""
-            destination = msg["destination"]
-            ami = msg["extra"]["id"]
             url = "https://redirect.fedoraproject.org/console.aws.amazon.com/ec2/v2/home?"
-            url += f"region={destination}#LaunchInstanceWizard:ami={ami}"
-            return f"| {destination}\n| {ami}\n| [{url} Launch in EC2]\n|-\n"
+            url += f"region={region}#LaunchInstanceWizard:ami={ami}"
+            return f"| {region}\n| {ami}\n| [{url} Launch in EC2]\n|-\n"
 
-        def _table(arch, virttype, voltype):
+        def _table(arch):
             """Convenience function for adding a table."""
-            ret = f"== {arch} {virttype} {voltype} AMIs ==\n\n"
+            ret = f"== {arch} AMIs ==\n\n"
             ret += '{| class="wikitable sortable mw-collapsible'
-            if arch != "x86_64" or virttype != "hvm" or voltype != "standard":
-                # we expand the x86_64 hvm standard table by default
-                ret += " mw-collapsed"
             ret += '" width=100%\n|-\n'
             ret += "! Region !! AMI ID !! Direct launch link\n|-\n"
-            # find the right messages for this arch and types
-            relevants = [
-                msg
-                for msg in ours
-                if msg["architecture"] == arch
-                and msg["extra"]["virt_type"] == virttype
-                and msg["extra"]["vol_type"] == voltype
-            ]
-            # sort the messages by region so the table is easier to scan
-            relevants.sort(key=lambda x: x["destination"])
+            # find the right messages for this arch
+            relevants = [msg for msg in ours if msg["architecture"] == arch]
+            if not relevants:
+                return ""
             for msg in relevants:
-                ret += _table_line(msg)
+                for region, ami in msg["regions"].items():
+                    ret += _table_line(region, ami)
             ret += "|}\n\n"
             return ret
 
         # now let's create and populate the tables
-        for arch in ("x86_64", "arm64"):
-            for virttype in ("hvm",):
-                for voltype in ("standard", "gp2"):
-                    text += _table(arch, virttype, voltype)
+        for arch in arches:
+            newtext = _table(arch)
+            if newtext:
+                text += newtext
 
         return text
 
