@@ -772,10 +772,10 @@ class Wiki(mwclient.Site):
         # representing results that were 'dupes'. We then reconstruct
         # a ResTuple for each dupe, and return the lists of insuffs
         # and dupes.
-        for (page, resdict) in pagedict.values():
+        for page, resdict in pagedict.values():
             if page:
                 _dupes = page.add_results(resdict, allowdupe)
-                for (row, env, result) in _dupes:
+                for row, env, result in _dupes:
                     dupes.append(
                         ResTuple(
                             page.testtype,
