@@ -169,6 +169,9 @@ class TestEventFedfind:
     return_value=["Installation", "Base", "Server", "Cloud", "Desktop"],
 )
 @mock.patch("fedfind.release.BranchedNightly.cid", "Fedora-27-20171104.n.0")
+# this is to fake out the AMI page creator, the data is a retcon
+# as we used fedimg at F27 time but wikitcms no longer supports
+# those messages (plus the topic is a lie to keep line length short)
 @mock.patch(
     "fedfind.helpers.download_json",
     return_value={
@@ -180,15 +183,15 @@ class TestEventFedfind:
             {
                 "msg": {
                     "architecture": "x86_64",
-                    "compose": "Fedora-27-20171104.n.0",
-                    "destination": "eu-west-2",
-                    "extra": {
-                        "id": "ami-085e29c4cd80e326d",
-                        "virt_type": "hvm",
-                        "vol_type": "gp2",
+                    "compose_id": "Fedora-27-20171104.n.0",
+                    "image_name": "Fedora-Cloud-Base-AmazonEC2.x86_64-27-20171104.n.0",
+                    "regions": {
+                        "af-south-1": "ami-0347e39249b17f533",
+                        "ap-east-1": "ami-02607d52d5570b15e",
                     },
-                }
-            }
+                },
+                "topic": "org.fedoraproject.prod.fedora_image_uploader.published.v1.aws",
+            },
         ],
     },
 )
