@@ -79,14 +79,14 @@ class TestHelpers:
     def test_fedora_release_sort(self):
         """Test for fedora_release_sort."""
         rels = OLD_SORTS + STANDARD_SORTS
-        for (num, rel) in enumerate(rels[1:], 1):
+        for num, rel in enumerate(rels[1:], 1):
             prevrel = rels[num - 1]
             assert hl.fedora_release_sort(" ".join(rel)) > hl.fedora_release_sort(" ".join(prevrel))
 
     def test_triplet_sort(self):
         """Test for triplet_sort and triplet_unsort."""
         rels = HARD_SORTS + OLD_SORTS + STANDARD_SORTS
-        for (num, rel) in enumerate(rels[1:], 1):
+        for num, rel in enumerate(rels[1:], 1):
             prevrel = rels[num - 1]
             sorttup = hl.triplet_sort(*rel)
             assert sorttup > hl.triplet_sort(*prevrel)
@@ -148,16 +148,33 @@ class TestHelpers:
             hl.cid_to_event("Fedora-27-updates-testing-20180711.0")
         with pytest.raises(ValueError):
             hl.cid_to_event("Fedora-27-updates-20180711.0")
+        # check we fail intentionally on non-digit, non-rawhide composes
+        with pytest.raises(ValueError):
+            hl.cid_to_event("Fedora-ELN-20240829.n.1")
 
     @mock.patch("fedfind.helpers.get_current_release", return_value=23, autospec=True)
     @mock.patch("fedfind.release.Production.cid", "Fedora-24-20160314.1")
     @mock.patch("fedfind.release.Production.label", "")
-    def test_cid_to_event_fail(self, fakecurr):
+    @mock.patch("fedfind.release.Production.status", "FINISHED")
+    def test_cid_to_event_fail_no_label(self, fakecurr):
         """Test to check cid_to_event fails if we cannot determine
-        label for production compose.
+        label for production compose (no label case).
         """
-        with pytest.raises(ValueError):
+        with pytest.raises(ValueError) as excinfo:
             hl.cid_to_event("Fedora-24-20160314.1")
+        assert "found no label" in str(excinfo.value)
+
+    @mock.patch("fedfind.helpers.get_current_release", return_value=23, autospec=True)
+    @mock.patch("fedfind.release.Production.cid", "Fedora-24-20160314.1")
+    @mock.patch("fedfind.release.Production.status", "DOOMED")
+    @mock.patch("fedfind.release.Production.exists", False)
+    def test_cid_to_event_fail_doomed(self, fakecurr):
+        """Test to check cid_to_event fails if we cannot determine
+        label for production compose (compose failed case).
+        """
+        with pytest.raises(ValueError) as excinfo:
+            hl.cid_to_event("Fedora-24-20160314.1")
+        assert "Compose Fedora-24-20160314.1 failed" in str(excinfo.value)
 
 
 # vim: set textwidth=100 ts=8 et sw=4:
