@@ -221,6 +221,15 @@ class TestListing:
         assert pg.date == "2012-03-14"
         assert pg.subject == ""
 
+    def test_pages_matrix(self):
+        """Matrix template pages."""
+        pg = self.site.pages["Template:Base_test_matrix"]
+        assert isinstance(pg, wikitcms.page.ResultPage)
+        iotpg = self.site.pages["Template:General_IoT_test_matrix"]
+        assert isinstance(iotpg, wikitcms.page.ResultPage)
+        notmpg = self.site.pages["Template:Something_else"]
+        assert not isinstance(notmpg, wikitcms.page.ResultPage)
+
     # we're just mocking this so we can count the calls
     @mock.patch("wikitcms.listing.PageCheckWarning.__init__", autospec=True, return_value=None)
     def test_pages_checkname(self, fakepagecheck):
