@@ -791,7 +791,7 @@ class TestAMIPage:
     """Tests for the AMIPage class."""
 
     # we have to patch these to avoid network round trips in fedfind
-    @mock.patch("fedfind.release.Compose.cid", "Fedora-32-20200312.0")
+    @mock.patch("fedfind.release.Compose.cid", "Fedora-42-20250312.0")
     @mock.patch("fedfind.release.Compose.exists", True)
     def test_ami_page(self):
         """Test for AMIPage. As with DownloadPage, it's hard to split
@@ -799,40 +799,45 @@ class TestAMIPage:
         less) and check the output is as expected.
         """
         site = wikitcms.wiki.Wiki("fjajah", do_init=False, force_login=False)
-        event = wikitcms.event.ComposeEvent(site, "32", "Beta", "1.2", cid="Fedora-32-20200312.0")
+        event = wikitcms.event.ComposeEvent(site, "42", "Beta", "1.4", cid="Fedora-42-20250312.0")
         page = event.ami_page
-        assert page.checkname == "Template:Fedora 32 Beta 1.2 AMI"
-        assert page.summary == "Relval bot-created AMI page for Fedora 32 Beta 1.2"
+        assert page.checkname == "Template:Fedora 42 Beta 1.4 AMI"
+        assert page.summary == "Relval bot-created AMI page for Fedora 42 Beta 1.4"
         assert page.event is event
+        urls = []
 
         def fakedownloadjson(url):
             """Mock for fedfind.helpers.download_json to fake up a
             datagrepper query response used to find the AMIs. The data
-            that backs this is close to but not quite 'real' data -
-            it's the real message dicts only of the messages that were
-            actually for this compose, plus *one* message that wasn't
-            (to test that filtering those out works), with the headers
-            and most of the additional data in the query response
-            dropped. The *real* real data for the relevant two days
-            is like 25 pages long, so we had to filter it. We hack up
-            splitting it across two 'pages' to test the pagination
-            handling.
+            that backs this is the real data, but we hack up splitting
+            it across two 'pages' to test the pagination handling.
             """
+            urls.append(url)
             page = 1
             if "page=2" in url:
                 # dumb but enough
                 page = 2
-            path = os.path.join(DATAPATH, "Fedora-32-20200312.0.ami.dgdata.{0}.json".format(page))
+            path = os.path.join(DATAPATH, f"Fedora-42-20250312.0.ami.dgdata.{page}.json")
             with open(path, "r") as amifh:
                 amidata = json.load(amifh)
             return amidata
 
         # again, read expected seedtext from a file
-        exptextpath = os.path.join(DATAPATH, "Template:Fedora 32 Beta 1.2 AMI.seedtext")
+        exptextpath = os.path.join(DATAPATH, "Template:Fedora 42 Beta 1.4 AMI.seedtext")
         with open(exptextpath, "r") as exptextfh:
             exptext = exptextfh.read()
         with mock.patch("fedfind.helpers.download_json", fakedownloadjson):
             assert page.seedtext == exptext
+            assert urls == [
+                "https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod"
+                ".fedora_image_uploader.published.v1.aws.beta.Cloud_Base.x86_64&topic=org"
+                ".fedoraproject.prod.fedora_image_uploader.published.v1.aws.beta.Cloud_Base"
+                ".aarch64&start=1741737600.0&end=1741910400.0",
+                "https://apps.fedoraproject.org/datagrepper/raw?topic=org.fedoraproject.prod"
+                ".fedora_image_uploader.published.v1.aws.beta.Cloud_Base.x86_64&topic=org"
+                ".fedoraproject.prod.fedora_image_uploader.published.v1.aws.beta.Cloud_Base"
+                ".aarch64&start=1741737600.0&end=1741910400.0&page=2",
+            ]
 
 
 @pytest.mark.usefixtures("fakemwp")
